@@ -1,6 +1,6 @@
 package Qiniu;
 
-our $VERSION  = '0.02';
+our $VERSION  = '0.03';
 
 1;
 
@@ -60,9 +60,9 @@ __END__
 
 要接入七牛云存储,您需要拥有一对有效的 Access Key 和 Secret Key 用来进行签名认证。可以通过如下步骤获得:
 
-1. L<https://portal.qiniu.com/signup|开通七牛开发者帐号>
+1. L<开通七牛开发者帐号|https://portal.qiniu.com/signup>
 
-2. 登录七牛开发者自助平台,查看 L<https://portal.qiniu.com/setting/key|Access Key 和 Secret Key>
+2. 登录七牛开发者自助平台,查看 L<Access Key 和 Secret Key|https://portal.qiniu.com/setting/key>
 
 =head1 属性
 
